##
##  dragon.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2013 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_dragon  1.3.10
%define       V_lfcbase 1.5.4

#   package information
Name:         dragon
Summary:      Dragon Parser Generator
URL:          http://www.lemke-it.com/opensource.html
Vendor:       Bjrn Lemke
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        EVAL
Group:        CompilerCompiler
License:      GPL
Version:      %{V_dragon}
Release:      20130521

#   list of sources
Source0:      http://www.lemke-it.com/dragon-%{V_dragon}.tar.gz
Source1:      http://www.lemke-it.com/lfcbase-%{V_lfcbase}.tar.gz
Patch0:       dragon.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101, gcc, gcc::with_cxx = yes
PreReq:       OpenPKG, openpkg >= 20100101

%description
    The dragon software package implements a combined scanner/parser
    generator for LR compliant grammar definitions. The generated
    C++ parser class is used as a super class from which a parser
    implementation class must be derived. The implementation class
    implements the scanner feed methods but also all required semantic
    action method. dragon has been used for several large projects with
    complex grammar defintions (about 200 productions / 80 tokens).
    Since for those grammar defintions, the analyse phase to build up
    the parse table is quite CPU intensive, it is recommended to use
    state of the art hardware. dragon requires the base package to get
    compiled but also for the compilation of the generated C++ code.

%track
    prog dragon:lfcbase = {
        version   = %{V_lfcbase}
        url       = http://www.lemke-it.com/litexec?request=pubdownlfcxml&user=&lang=en
        regex     = lfcbase-(__VER__)\.tar\.gz
    }
    prog dragon:dragon = {
        version   = %{V_dragon}
        url       = http://www.lemke-it.com/litexec?request=pubdowndragon&user=&lang=en
        regex     = dragon-(__VER__)\.tar\.gz
    }

%prep
    %setup -q -c
    %setup -q -T -D -a 1
    %patch -p0

%build
    ( cd lfcbase-%{V_lfcbase}
      export CC="%{l_cc}"
      export CXX="%{l_cxx}"
      export CFLAGS="%{l_cflags -O}"
      export CXXFLAGS="%{l_cxxflags -O}"
      export CPPFLAGS="%{l_cppflags}"
      export LDFLAGS="%{l_ldflags}"
      ./configure \
          --prefix=%{l_prefix} \
          --disable-shared
      %{l_make} %{l_mflags}
      ln -s src lfcbase
    ) || exit $?
    ( cd dragon-%{V_dragon}
      export CC="%{l_cc}"
      export CXX="%{l_cxx}"
      export CFLAGS="%{l_cflags -O}"
      export CXXFLAGS="%{l_cxxflags -O}"
      export CPPFLAGS="%{l_cppflags} -I`pwd`/../lfcbase-%{V_lfcbase} -I`pwd`/../lfcbase-%{V_lfcbase}/src"
      export LDFLAGS="%{l_ldflags} -L`pwd`/../lfcbase-%{V_lfcbase}/src -L`pwd`/../lfcbase-%{V_lfcbase}/src/.libs"
      ./configure \
          --prefix=%{l_prefix} \
          --disable-shared
      %{l_make} %{l_mflags}
    ) || exit $?

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    ( cd dragon-%{V_dragon}
      %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    ) || exit $?
    %{l_shtool} install -c -m 644 \
        dragon-%{V_dragon}/man/dragon.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std}

%files -f files

%clean

